/*
Example for Brushless_2 Click

    Date          : jul 2017.
    Author        : MikroE Team

Test configuration PIC :
    
    MCU             : P18F87K22
    Dev. Board      : EasyPIC PRO v7
    SW              : mikroC PRO for PIC v7.1.0

Description :

    This simple example demonstrates driving the motor with Brushless 2 click, 
    direction of motor is controled via MOTOR_DIR_PIN and speed is regulated with PWM.
    Board specific: Button press level PB to VCC, and PORTB pull down RB1 and RB5, 
    speed is controlled by pressing RB1 and direction is changed by pressing RB5.
*/
#include "stdint.h"

sbit MOTOR_DIR_PIN at PORTC.B0;
sbit MOTOR_DIR_PIN_Direction at TRISC.B0;

uint8_t const maxPwmDuty = 255;
uint8_t currentDuty = 20 ;
uint8_t oldstate = 0;

void systemInit()
{
    ANCON0 = 0x00;
    ANCON1 = 0x00;
    ANCON2 = 0x00;
    PWM2_Init(5000);
    PWM2_Start();
    PWM2_Set_Duty(currentDuty);
    MOTOR_DIR_PIN_Direction = 0;
}

void Brushless_2_Init()
{
    MOTOR_DIR_PIN = 1;
}

void Brushless_2_Task()
{
    if (Button(&PORTB, 1, 1, 1))
    {
        currentDuty++;
        PWM2_Set_Duty(currentDuty);
        if (currentDuty > maxPwmDuty)      
            currentDuty = 0;              
        
    }
     
    if (Button(&PORTB, 5, 1, 1)) 
    {                                               
        oldstate = 1;                              
    }
    if (oldstate && Button(&PORTB, 5, 1, 0)) 
    {   
        MOTOR_DIR_PIN = ~MOTOR_DIR_PIN;                              
        oldstate = 0;   
    }                               
}

void main()
{
    systemInit();
    Brushless_2_Init();

    while( 1 )
    {
            Brushless_2_Task();
    }
}